@@ -1,5 +1,5 @@
-// Copyright (C) 2011 NICTA (www.nicta.com.au)
-// Copyright (C) 2011 Conrad Sanderson
+// Copyright (C) 2011-2013 NICTA (www.nicta.com.au)
+// Copyright (C) 2011-2013 Conrad Sanderson
 // 
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -20,6 +20,7 @@ class GenCube : public BaseCube<eT, GenCube<eT, gen_type> >
   typedef typename get_pod_type<elem_type>::result pod_type;
   
   static const bool prefer_at_accessor = false;
+  static const bool is_simple          = (is_same_type<gen_type, gen_ones_full>::value) || (is_same_type<gen_type, gen_zeros>::value); 
   
   arma_aligned const uword n_rows;
   arma_aligned const uword n_cols;
@@ -32,6 +33,7 @@ class GenCube : public BaseCube<eT, GenCube<eT, gen_type> >
   
   arma_inline eT operator[] (const uword i)                                       const;
   arma_inline eT at         (const uword row, const uword col, const uword slice) const;
+  arma_inline eT at_alt     (const uword i)                                       const;
   
   inline void apply              (Cube<eT>& out) const;
   inline void apply_inplace_plus (Cube<eT>& out) const;
