@@ -76,13 +76,17 @@ eGlue<T1,T2,eglue_type>::operator[] (const uword ii) const
   {
   // the optimiser will keep only one return statement
   
+  typedef typename T1::elem_type eT;
+  
        if(is_same_type<eglue_type, eglue_plus >::value == true) { return P1[ii] + P2[ii]; }
   else if(is_same_type<eglue_type, eglue_minus>::value == true) { return P1[ii] - P2[ii]; }
   else if(is_same_type<eglue_type, eglue_div  >::value == true) { return P1[ii] / P2[ii]; }
   else if(is_same_type<eglue_type, eglue_schur>::value == true) { return P1[ii] * P2[ii]; }
+  else return eT(0);
   }
 
 
+
 template<typename T1, typename T2, typename eglue_type>
 arma_inline
 typename T1::elem_type
@@ -90,10 +94,13 @@ eGlue<T1,T2,eglue_type>::at(const uword row, const uword col) const
   {
   // the optimiser will keep only one return statement
   
+  typedef typename T1::elem_type eT;
+  
        if(is_same_type<eglue_type, eglue_plus >::value == true) { return P1.at(row,col) + P2.at(row,col); }
   else if(is_same_type<eglue_type, eglue_minus>::value == true) { return P1.at(row,col) - P2.at(row,col); }
   else if(is_same_type<eglue_type, eglue_div  >::value == true) { return P1.at(row,col) / P2.at(row,col); }
   else if(is_same_type<eglue_type, eglue_schur>::value == true) { return P1.at(row,col) * P2.at(row,col); }
+  else return eT(0);
   }
 
 
@@ -105,10 +112,13 @@ eGlue<T1,T2,eglue_type>::at_alt(const uword ii) const
   {
   // the optimiser will keep only one return statement
   
+  typedef typename T1::elem_type eT;
+  
        if(is_same_type<eglue_type, eglue_plus >::value == true) { return P1.at_alt(ii) + P2.at_alt(ii); }
   else if(is_same_type<eglue_type, eglue_minus>::value == true) { return P1.at_alt(ii) - P2.at_alt(ii); }
   else if(is_same_type<eglue_type, eglue_div  >::value == true) { return P1.at_alt(ii) / P2.at_alt(ii); }
   else if(is_same_type<eglue_type, eglue_schur>::value == true) { return P1.at_alt(ii) * P2.at_alt(ii); }
+  else return eT(0);
   }
 
 
