@@ -2,14 +2,9 @@
 // Copyright (C) 2009-2010 Conrad Sanderson
 // Copyright (C) 2009-2010 Dimitrios Bouzas
 // 
-// This file is part of the Armadillo C++ library.
-// It is provided without any warranty of fitness
-// for any purpose. You can redistribute this file
-// and/or modify it under the terms of the GNU
-// Lesser General Public License (LGPL) as published
-// by the Free Software Foundation, either version 3
-// of the License or (at your option) any later version.
-// (see http://www.opensource.org/licenses for more info)
+// This Source Code Form is subject to the terms of the Mozilla Public
+// License, v. 2.0. If a copy of the MPL was not distributed with this
+// file, You can obtain one at http://mozilla.org/MPL/2.0/.
 
 
 
@@ -83,7 +78,7 @@ eps(const eT& x)
 template<typename eT>
 arma_inline
 arma_warn_unused
-typename arma_float_only<eT>::result
+typename arma_real_only<eT>::result
 eps(const eT& x)
   {
   return eop_aux::direct_eps(x);
@@ -94,7 +89,7 @@ eps(const eT& x)
 template<typename T>
 arma_inline
 arma_warn_unused
-typename arma_float_only<T>::result
+typename arma_real_only<T>::result
 eps(const std::complex<T>& x)
   {
   return eop_aux::direct_eps(x);
